@@ -1,16 +1,16 @@
-# tk2tip.R - Tooltips for Tk widgets
-# Copyright (c), Philippe Grosjean (phgrosjean@sciviews.org)
-# Licensed under LGPL 3 or above
-#
-# Changes:
-# - 2007-01-01: fisrt version (for tcltk2_1.0-0)
-#
-# To do:
-# - add and check catch instructions here
+### tk2tip.R - Tooltips for Tk widgets
+### Copyright (c), Philippe Grosjean (phgrosjean@sciviews.org)
+### Licensed under LGPL 3 or above
+###
+### Changes:
+### - 2007-01-01: fisrt version (for tcltk2_1.0-0)
+###
+### To do:
+### - add and check catch instructions here
 
-"tk2tip" <- function(widget, message) {
+tk2tip <- function (widget, message)
+{
 	if (!is.tk()) stop("Package Tk is required but not loaded")
-	#tcl("set_balloon", widget, message)
 	res <- tclRequire("tooltip")
 	if (inherits(res, "tclObj")) {
 		res <- tcl("tooltip::tooltip", widget, message)
@@ -18,7 +18,8 @@
 	return(invisible(res))
 }
 
-"tk2killtip" <- function() {
+tk2killtip <- function ()
+{
 	if (!is.tk()) stop("Package Tk is required but not loaded")
 	return(invisible(tcl("tooltip::hide")))
 }
